@@ -37,7 +37,7 @@ Authors email : jonas.frantz@helsinki.fi
 #include "gperiodic.h"
 #include "table_data.h"
 
-#define VERSION "2.0.9"
+#define VERSION "2.0.10"
 
 #define PACKAGE "gperiodic"
 #define GPERIODIC_LOCALE_DIR "/usr/share/locale"
@@ -48,6 +48,8 @@ Authors email : jonas.frantz@helsinki.fi
   int  enable_colorscale  = 0;
   int  debug = 0;
 
+  GtkWidget *window;
+
 int gpdata_get_atomic_number_for_symbol(const char*sym)
 {
   int i;
@@ -162,63 +164,23 @@ GCallback menu_file_exit(void)
     main_window_exit(NULL,NULL);
 }
 
-GCallback menu_help_about(void) 
+
+GCallback menu_help_about(void)
 {
-  GtkWidget *ok_button    = NULL;
-  GtkWidget *about_dialog = NULL;
-  GtkWidget *label        = NULL;
-  gchar *buff;
+  gchar *authors[] = AUTHORS;
 
-  char *version = "\t<big><b>GPeriodic "VERSION"</b></big>\n\n";
+    gtk_show_about_dialog((GtkWindow *) window, 
+	"authors", authors, 
+	"comments", COMMENTS,
+	"copyright", COPYRIGHT,
+	"license", LICENSE,
+	"name", PROGNAME,
+	"version", VERSION,
+	"website", HOMEPAGEURL,
+	"website-label", HOMEPAGELABEL,
+	NULL);
 
-  char *authors = "\tjonas.frantz@welho.com\n"
-		  "\tmortis@voicenet.com\n"
-		  "\tpicio@bogucice.pl\n"
-		  "\ta.w.peters@ieee.org\n"
-		  "\tkhazuada@univ-littoral.fr\n"
-		  "\trmrivera@cable.net.co\n"
-		  "\tchris@koeln.ccc.de\n"
-		  "\tlalo@webcom.com\n"
-		  "\tneumanns@uni-duesseldorf.de\n"
-		  "\tkoen_kooi@hotmail.com\n"
-		  "\tantigone34@libero.it\n"
-		  "\tAmbrogio.Oliva@sanofi-synthelabo.fr\n"
-		  "\tf.natter@ndh.net\n"
-		  "\tmike@lic145.kiev.ua\n"
-		  "\talipiec@elka.pw.edu.pl\n"
-                  "\tdaniel.leidert@wgdd.de\n"
-                  "\tleandro.regueiro@gmail.com";
-
-  char *info = _("%s<u>Authors:</u>\n%s\n\n"
-		 "This program shows the periodic table of elements\n"
-		 "and information about these elements.\n\n"
-		 "Released under the GPL license.");
-
-    about_dialog = gtk_dialog_new();
-
-    g_signal_connect(GTK_OBJECT(about_dialog), "destroy", G_CALLBACK(dialog_destroy),
-		     about_dialog );
-
-    gtk_window_set_title(GTK_WINDOW(about_dialog), _("GPeriodic - About"));
-    gtk_container_set_border_width( GTK_CONTAINER(about_dialog), 5 );
-    gtk_window_set_resizable(GTK_WINDOW(about_dialog),0);
-
-    buff = g_strdup_printf(info, version, authors);
-    label = gtk_label_new("");
-    gtk_label_set_markup(GTK_LABEL(label),buff);
-    free(buff);
-
-    gtk_misc_set_padding( GTK_MISC(label), 10, 10 );
-
-    gtk_box_pack_start( GTK_BOX(GTK_DIALOG(about_dialog)->vbox), label, TRUE, TRUE, 0 );
-
-    ok_button = gtk_button_new_from_stock (GTK_STOCK_OK);
-
-    g_signal_connect( GTK_OBJECT(ok_button), "clicked", G_CALLBACK(dialog_close), about_dialog );
-
-    gtk_box_pack_start( GTK_BOX( GTK_DIALOG(about_dialog)->action_area ), ok_button, TRUE, TRUE, 0 );
-
-    gtk_widget_show_all(about_dialog);
+  return NULL;
 }
 
 
@@ -287,7 +249,6 @@ void colorize_element(
 
 void main_prog(void)
 {
-  GtkWidget *window;
   GtkWidget *vbox;
   GtkWidget *periodic_table;
   int menu_num_items;
